.. title:: bmi-geotiff

.. include:: README.rst


API Reference
=============

Looking for information on a particular function, class, or method?
This part of the documentation is for you.

.. toctree::
   :maxdepth: 2

   api/index


Additional Information
======================

.. toctree::
   :maxdepth: 2

   changelog
   license

Help
----

Depending on your need, CSDMS can provide advice or consulting services.
Feel free to contact us through the `CSDMS Help Desk <https://github.com/csdms/help-desk>`_.

Acknowledgments
---------------

This work is supported by the National Science Foundation
under Award No. `1831623 <https://nsf.gov/awardsearch/showAward?AWD_ID=1831623>`_,
*Community Facility Support: The Community Surface Dynamics Modeling System (CSDMS)*.

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
